@@ -28,7 +28,6 @@ osmo-build-dep.sh asn1c aper-prefix
 
 CONFIG=""
 if [ "$WITH_MANUALS" = "1" ]; then
-	osmo-build-dep.sh osmo-gsm-manuals
 	CONFIG="--enable-manuals"
 fi
 
@@ -60,12 +59,8 @@ fi
 $MAKE $PARALLEL_MAKE
 $MAKE check \
   || cat-testlogs.sh
-$MAKE distcheck \
+$MAKE $PARALLEL_MAKE distcheck \
   || cat-testlogs.sh
 
-if [ "$WITH_MANUALS" = "1" ] && [ "$PUBLISH" = "1" ]; then
-	make -C "$base/doc/manuals" publish
-fi
-
-$MAKE maintainer-clean
+$MAKE $PARALLEL_MAKE maintainer-clean
 osmo-clean-workspace.sh
