@@ -596,6 +596,9 @@ struct gprs_ra_id;
 extern int _ranap_DRANAP;
 #define RANAP_DEBUG(x, args ...) DEBUGP(_ranap_DRANAP, x, ## args)
 
+/* Callback to be used with decoder functions in ranap_common_cn.c  ranap_common_ran.c */
+typedef void (*ranap_handle_cb)(void *ctx, ranap_message *ranap_msg);
+
 extern int asn1_xer_print;
 
 extern const struct value_string ranap_presence_vals[5];
@@ -641,5 +644,20 @@ int ranap_ip_from_transp_layer_addr(const BIT_STRING_t *in, uint32_t *ip);
 
 /* The generated version does not work, this is a custom one */
 int ranap_decode_rab_setupormodifieditemies_fromlist(
-    RANAP_RAB_SetupOrModifiedItemIEs_t *raB_SetupOrModifiedItemIEs,
-    ANY_t *any_p);
+	RANAP_RAB_SetupOrModifiedItemIEs_t *raB_SetupOrModifiedItemIEs,
+	ANY_t *any_p);
+
+/* There is no generated decoder available, this is a custom one */
+int ranap_decode_rab_faileditemies_fromlist(
+	RANAP_RAB_FailedItemIEs_t *raB_FailedItemIEs,
+	ANY_t *any_p);
+
+/* There is no generated decoder available, this is a custom one */
+int ranap_decode_rab_releaseitemies_fromlist(
+	RANAP_RAB_ReleaseItemIEs_t *raB_ReleaseItemIEs,
+	ANY_t *any_p);
+
+/* There is no generated decoder available, this is a custom one */
+int ranap_decode_rab_setupormodifyitemfirst(
+	RANAP_RAB_SetupOrModifyItemFirst_t *raB_SetupOrModifyItemFirst,
+	ANY_t *any_p);
