@@ -78,10 +78,11 @@ struct hnb_test g_hnb_test = {
 
 struct msgb *rua_new_udt(struct msgb *inmsg);
 
+#if 0
 static int hnb_test_ue_de_register_tx(struct hnb_test *hnb_test)
 {
 	struct msgb *msg;
-	int rc, imsi_len;
+	int rc;
 	uint32_t ctx_id;
 
 	UEDe_Register_t dereg;
@@ -94,6 +95,7 @@ static int hnb_test_ue_de_register_tx(struct hnb_test *hnb_test)
 
 	memset(&dereg, 0, sizeof(dereg));
 	rc = hnbap_encode_uede_registeries(&dereg, &dereg_ies);
+	OSMO_ASSERT(rc == 0);
 
 	msg = hnbap_generate_initiating_message(ProcedureCode_id_UEDe_Register,
 						Criticality_ignore,
@@ -106,36 +108,38 @@ static int hnb_test_ue_de_register_tx(struct hnb_test *hnb_test)
 
 	return osmo_wqueue_enqueue(&hnb_test->wqueue, msg);
 }
+#endif
 
 static int hnb_test_ue_register_tx(struct hnb_test *hnb_test, const char *imsi_str)
 {
 	struct msgb *msg;
 	int rc, imsi_len;
 
-	char imsi_buf[16];
+	uint8_t imsi_buf[16];
 
-	UERegisterRequest_t request_out;
-	UERegisterRequestIEs_t request;
+	HNBAP_UERegisterRequest_t request_out;
+	HNBAP_UERegisterRequestIEs_t request;
 	memset(&request, 0, sizeof(request));
 
-	request.uE_Identity.present = UE_Identity_PR_iMSI;
+	request.uE_Identity.present = HNBAP_UE_Identity_PR_iMSI;
 
 	imsi_len = ranap_imsi_encode(imsi_buf, sizeof(imsi_buf), imsi_str);
-	OCTET_STRING_fromBuf(&request.uE_Identity.choice.iMSI, imsi_buf, imsi_len);
+	OCTET_STRING_fromBuf(&request.uE_Identity.choice.iMSI, (const char*)imsi_buf, imsi_len);
 
-	request.registration_Cause = Registration_Cause_normal;
-	request.uE_Capabilities.access_stratum_release_indicator = Access_stratum_release_indicator_rel_6;
-	request.uE_Capabilities.csg_capability = CSG_Capability_not_csg_capable;
+	request.registration_Cause = HNBAP_Registration_Cause_normal;
+	request.uE_Capabilities.access_stratum_release_indicator = HNBAP_Access_stratum_release_indicator_rel_6;
+	request.uE_Capabilities.csg_capability = HNBAP_CSG_Capability_not_csg_capable;
 
 	memset(&request_out, 0, sizeof(request_out));
 	rc = hnbap_encode_ueregisterrequesties(&request_out, &request);
+	OSMO_ASSERT(rc == 0);
 
-	msg = hnbap_generate_initiating_message(ProcedureCode_id_UERegister,
-						Criticality_reject,
-						&asn_DEF_UERegisterRequest,
+	msg = hnbap_generate_initiating_message(HNBAP_ProcedureCode_id_UERegister,
+						HNBAP_Criticality_reject,
+						&asn_DEF_HNBAP_UERegisterRequest,
 						&request_out);
 
-	ASN_STRUCT_FREE_CONTENTS_ONLY(asn_DEF_UERegisterRequest, &request_out);
+	ASN_STRUCT_FREE_CONTENTS_ONLY(asn_DEF_HNBAP_UERegisterRequest, &request_out);
 
 	msgb_sctp_ppid(msg) = IUH_PPI_HNBAP;
 
@@ -145,7 +149,7 @@ static int hnb_test_ue_register_tx(struct hnb_test *hnb_test, const char *imsi_s
 static int hnb_test_rx_hnb_register_acc(struct hnb_test *hnb, ANY_t *in)
 {
 	int rc;
-	HNBRegisterAcceptIEs_t accept;
+	HNBAP_HNBRegisterAcceptIEs_t accept;
 
 	rc = hnbap_decode_hnbregisteraccepties(&accept, in);
 	if (rc < 0) {
@@ -162,7 +166,7 @@ static int hnb_test_rx_ue_register_acc(struct hnb_test *hnb, ANY_t *in)
 {
 	int rc;
 	uint32_t ctx_id;
-	UERegisterAcceptIEs_t accept;
+	HNBAP_UERegisterAcceptIEs_t accept;
 	char imsi[16];
 
 	rc = hnbap_decode_ueregisteraccepties(&accept, in);
@@ -170,7 +174,7 @@ static int hnb_test_rx_ue_register_acc(struct hnb_test *hnb, ANY_t *in)
 		return rc;
 	}
 
-	if (accept.uE_Identity.present != UE_Identity_PR_iMSI) {
+	if (accept.uE_Identity.present != HNBAP_UE_Identity_PR_iMSI) {
 		printf("Wrong type in UE register accept\n");
 		return -1;
 	}
@@ -320,13 +324,12 @@ static int hnb_test_nas_rx_auth_req(struct hnb_test *hnb, struct gsm48_hdr *gh,
 				    int len)
 {
 	struct gsm48_auth_req *ar;
-	int parse_res;
 
 	len -= (const char *)&gh->data[0] - (const char *)gh;
 
 	if (len < sizeof(*ar)) {
 		printf("GSM48 Auth Req does not fit.\n");
-		return;
+		return -1;
 	}
 
 	printf(" :) Authentication Request :)\n");
@@ -468,31 +471,32 @@ void hnb_test_rx_paging(struct hnb_test *hnb, const char *imsi)
 
 int hnb_test_hnbap_rx(struct hnb_test *hnb, struct msgb *msg)
 {
-	HNBAP_PDU_t _pdu, *pdu = &_pdu;
+	HNBAP_HNBAP_PDU_t _pdu, *pdu = &_pdu;
 	asn_dec_rval_t dec_ret;
 	int rc;
 
 	memset(pdu, 0, sizeof(*pdu));
-	dec_ret = aper_decode(NULL, &asn_DEF_HNBAP_PDU, (void **) &pdu,
+	dec_ret = aper_decode(NULL, &asn_DEF_HNBAP_HNBAP_PDU, (void **) &pdu,
 			      msg->data, msgb_length(msg), 0, 0);
 	if (dec_ret.code != RC_OK) {
 		LOGP(DMAIN, LOGL_ERROR, "Error in ASN.1 decode\n");
-		return rc;
+		return -EINVAL;
 	}
 
-	if (pdu->present != HNBAP_PDU_PR_successfulOutcome) {
+	if (pdu->present != HNBAP_HNBAP_PDU_PR_successfulOutcome) {
 		printf("Unexpected HNBAP message received\n");
 	}
 
 	switch (pdu->choice.successfulOutcome.procedureCode) {
-	case ProcedureCode_id_HNBRegister:
+	case HNBAP_ProcedureCode_id_HNBRegister:
 		/* Get HNB id and send UE Register request */
 		rc = hnb_test_rx_hnb_register_acc(hnb, &pdu->choice.successfulOutcome.value);
 		break;
-	case ProcedureCode_id_UERegister:
+	case HNBAP_ProcedureCode_id_UERegister:
 		rc = hnb_test_rx_ue_register_acc(hnb, &pdu->choice.successfulOutcome.value);
 		break;
 	default:
+		rc = -ENOSPC;
 		break;
 	}
 
@@ -505,14 +509,13 @@ int hnb_test_rua_rx(struct hnb_test *hnb, struct msgb *msg)
 {
 	RUA_RUA_PDU_t _pdu, *pdu = &_pdu;
 	asn_dec_rval_t dec_ret;
-	int rc;
 
 	memset(pdu, 0, sizeof(*pdu));
 	dec_ret = aper_decode(NULL, &asn_DEF_RUA_RUA_PDU, (void **) &pdu,
 			      msg->data, msgb_length(msg), 0, 0);
 	if (dec_ret.code != RC_OK) {
 		LOGP(DMAIN, LOGL_ERROR, "Error in ASN.1 decode\n");
-		return rc;
+		return -EINVAL;
 	}
 
 	switch (pdu->present) {
@@ -559,7 +562,7 @@ int hnb_test_rua_rx(struct hnb_test *hnb, struct msgb *msg)
 		break;
 	}
 
-	return rc;
+	return 0;
 }
 
 static int hnb_read_cb(struct osmo_fd *fd)
@@ -580,22 +583,22 @@ static int hnb_read_cb(struct osmo_fd *fd)
 		/* FIXME: clean up after disappeared HNB */
 		close(fd->fd);
 		osmo_fd_unregister(fd);
-		return rc;
+		goto free_ret;
 	} else if (rc == 0) {
 		LOGP(DMAIN, LOGL_INFO, "Connection to HNB closed\n");
 		close(fd->fd);
 		osmo_fd_unregister(fd);
 		fd->fd = -1;
-
-		return -1;
+		rc = -1;
+		goto free_ret;
 	} else {
 		msgb_put(msg, rc);
 	}
 
 	if (flags & MSG_NOTIFICATION) {
 		LOGP(DMAIN, LOGL_DEBUG, "Ignoring SCTP notification\n");
-		msgb_free(msg);
-		return 0;
+		rc = 0;
+		goto free_ret;
 	}
 
 	sinfo.sinfo_ppid = ntohl(sinfo.sinfo_ppid);
@@ -623,13 +626,14 @@ static int hnb_read_cb(struct osmo_fd *fd)
 		break;
 	}
 
+free_ret:
 	msgb_free(msg);
 	return rc;
 }
 
 static int hnb_write_cb(struct osmo_fd *fd, struct msgb *msg)
 {
-	struct hnb_test *ctx = fd->data;
+	/* struct hnb_test *ctx = fd->data; */
 	struct sctp_sndrcvinfo sinfo = {
 		.sinfo_ppid = htonl(msgb_sctp_ppid(msg)),
 		.sinfo_stream = 0,
@@ -645,7 +649,7 @@ static int hnb_write_cb(struct osmo_fd *fd, struct msgb *msg)
 
 static void hnb_send_register_req(struct hnb_test *hnb_test)
 {
-	HNBRegisterRequest_t request_out;
+	HNBAP_HNBRegisterRequest_t request_out;
 	struct msgb *msg;
 	int rc;
 	uint16_t lac, sac;
@@ -654,7 +658,7 @@ static void hnb_send_register_req(struct hnb_test *hnb_test)
 	uint8_t plmn[] = {0x09, 0xf1, 0x99};
 	char identity[50] = "ATestHNB@";
 
-	HNBRegisterRequestIEs_t request;
+	HNBAP_HNBRegisterRequestIEs_t request;
 	memset(&request, 0, sizeof(request));
 
 	lac = 0xc0fe;
@@ -667,7 +671,7 @@ static void hnb_send_register_req(struct hnb_test *hnb_test)
 	asn1_u8_to_str(&request.rac, &rac, rac);
 	asn1_u28_to_bitstring(&request.cellIdentity, &cid, cid);
 
-	request.hnB_Identity.hNB_Identity_Info.buf = identity;
+	request.hnB_Identity.hNB_Identity_Info.buf = (uint8_t*) identity;
 	request.hnB_Identity.hNB_Identity_Info.size = strlen(identity);
 
 	request.plmNidentity.buf = plmn;
@@ -681,9 +685,9 @@ static void hnb_send_register_req(struct hnb_test *hnb_test)
 		printf("Could not encode HNB register request IEs\n");
 	}
 
-	msg = hnbap_generate_initiating_message(ProcedureCode_id_HNBRegister,
-						Criticality_reject,
-						&asn_DEF_HNBRegisterRequest,
+	msg = hnbap_generate_initiating_message(HNBAP_ProcedureCode_id_HNBRegister,
+						HNBAP_Criticality_reject,
+						&asn_DEF_HNBAP_HNBRegisterRequest,
 						&request_out);
 
 
@@ -697,22 +701,22 @@ static void hnb_send_deregister_req(struct hnb_test *hnb_test)
 	struct msgb *msg;
 	int rc;
 
-	HNBDe_RegisterIEs_t request;
+	HNBAP_HNBDe_RegisterIEs_t request;
 	memset(&request, 0, sizeof(request));
 
-	request.cause.present = Cause_PR_misc;
-	request.cause.choice.misc = CauseMisc_o_and_m_intervention;
+	request.cause.present = HNBAP_Cause_PR_misc;
+	request.cause.choice.misc = HNBAP_CauseMisc_o_and_m_intervention;
 
-	HNBDe_Register_t request_out;
+	HNBAP_HNBDe_Register_t request_out;
 	memset(&request_out, 0, sizeof(request_out));
 	rc = hnbap_encode_hnbde_registeries(&request_out, &request);
 	if (rc < 0) {
 		printf("Could not encode HNB deregister request IEs\n");
 	}
 
-	msg = hnbap_generate_initiating_message(ProcedureCode_id_HNBDe_Register,
-						Criticality_reject,
-						&asn_DEF_HNBDe_Register,
+	msg = hnbap_generate_initiating_message(HNBAP_ProcedureCode_id_HNBDe_Register,
+						HNBAP_Criticality_reject,
+						&asn_DEF_HNBAP_HNBDe_Register,
 						&request_out);
 
 	msgb_sctp_ppid(msg) = IUH_PPI_HNBAP;
@@ -788,7 +792,7 @@ DEFUN(ue_register, ue_register_cmd,
 }
 
 DEFUN(asn_dbg, asn_dbg_cmd,
-	"asn-debug (1|0)", "Enable or disabel libasn1c debugging")
+	"asn-debug (1|0)", "Enable or disable libasn1c debugging")
 {
 	asn_debug = atoi(argv[0]);
 
@@ -941,6 +945,8 @@ int main(int argc, char **argv)
 
 	tall_hnb_ctx = talloc_named_const(NULL, 0, "hnb_context");
 
+	osmo_init_logging2(tall_hnb_ctx, &hnb_test_log_info);
+
 	vty_init(&vty_info);
 	hnbtest_vty_init();
 
