@@ -32,10 +32,6 @@
 
 #include "test_common.h"
 
-#include <osmocom/iuh/hnbgw.h>
-
-int asn1_xer_print = 1;
-
 extern void *tall_msgb_ctx;
 
 static void test_aper_int(uint32_t inp)
@@ -51,7 +47,7 @@ static void test_aper_int(uint32_t inp)
 		fprintf(stderr, "Failed\n");
 		return;
 	}
-	printf("Encoded MaxBitRate %u to %s\n", mbr, osmo_hexdump(buf, rv.encoded/8));
+	printf("Encoded MaxBitRate %ld to %s\n", mbr, osmo_hexdump(buf, rv.encoded/8));
 }
 
 static void test_aper_causemisc(uint32_t inp, uint8_t exp_enc)
@@ -75,13 +71,13 @@ static void test_aper_causemisc(uint32_t inp, uint8_t exp_enc)
 
 	/* test re-decoding */
 	aper_decode(NULL, &asn_DEF_RANAP_Cause, &c_dec, buf, 1, 0, 0);
-	printf("Decoded Cause Misc=%u\n", c_dec->choice.misc);
+	printf("Decoded Cause Misc=%ld\n", c_dec->choice.misc);
 	OSMO_ASSERT(c_dec->present == RANAP_Cause_PR_misc);
 	OSMO_ASSERT(c_dec->choice.misc == inp);
 	ASN_STRUCT_FREE(asn_DEF_RANAP_Cause, c_dec);
 }
 
-int main(int argc, char **argv)
+static void test_ranap_messages(void)
 {
 	uint8_t nas_buf[] = { 0xaa, 0xbb, 0xcc };
 	struct msgb *msg;
@@ -93,24 +89,7 @@ int main(int argc, char **argv)
 	uint32_t gtp_tei = 0x11223344;
 	uint8_t ik[16] = { 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1 };
 	uint8_t ck[16] = { 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2 };
-	int i, rc;
-
-	//asn_debug = 1;
-
-	test_common_init();
-
-	test_aper_int(1);
-	test_aper_int(2);
-	test_aper_int(3);
-	test_aper_int(255);
-	test_aper_int(256);
-	test_aper_int(257);
-	test_aper_int(64000);
-	test_aper_int(0xffff);
-	test_aper_int(0xffff+1);
-	test_aper_int(0xffff+2);
-	test_aper_int(16000000);
-	test_aper_causemisc(RANAP_CauseMisc_unspecified_failure, 0x42);
+	int i;
 
 	for (i = 0; i < 1; i++) {
 		printf("\n==> DIRECT TRANSFER\n");
@@ -192,6 +171,30 @@ int main(int argc, char **argv)
 			printf("%s\n", msgb_hexdump(msg));
 		msgb_free(msg);
 	}
+}
+
+int main(int argc, char **argv)
+{
+	asn1_xer_print = 1;
+
+	//asn_debug = 1;
+
+	test_common_init();
+	ranap_set_log_area(DRANAP);
+
+	test_aper_int(1);
+	test_aper_int(2);
+	test_aper_int(3);
+	test_aper_int(255);
+	test_aper_int(256);
+	test_aper_int(257);
+	test_aper_int(64000);
+	test_aper_int(0xffff);
+	test_aper_int(0xffff+1);
+	test_aper_int(0xffff+2);
+	test_aper_int(16000000);
+	test_aper_causemisc(RANAP_CauseMisc_unspecified_failure, 0x42);
+	test_ranap_messages();
 
 	printf("report\n");
 	talloc_report(talloc_asn1_ctx, stdout);
